<?php
require_once 'smtp_auth.php';
require_once 'send_email.php';
require_once 'logger.php';
require_once 'rate_limit.php';

$config = require 'config.php';

function select_account($config) {
    echo "Available accounts:\n";
    foreach ($config['accounts'] as $key => $account) {
        echo "$key: {$account['name']} ({$account['email']})\n";
    }
    $selected = readline("Select an account: ");
    return $config['accounts'][$selected] ?? null;
}

function get_email_details() {
    $to = readline("To: ");
    $subject = readline("Subject: ");
    $body = readline("Body: ");
    $cc = readline("CC (comma-separated, leave blank if none): ");
    $bcc = readline("BCC (comma-separated, leave blank if none): ");
    $attachment = readline("Attachment file path (leave blank if none): ");

    return [
        'to' => $to,
        'subject' => $subject,
        'body' => $body,
        'cc' => $cc ? explode(',', $cc) : [],
        'bcc' => $bcc ? explode(',', $bcc) : [],
        'attachment' => $attachment,
    ];
}

$account = select_account($config);
if (!$account) {
    die("Invalid account selected.\n");
}

if (!check_rate_limit($config, $account['email'])) {
    die("Daily email limit reached for {$account['email']}.\n");
}

$email_details = get_email_details();

try {
    $smtp = authenticate_smtp($account['email'], $account['password']);
    
    $attachments = [];
    if ($email_details['attachment'] && file_exists($email_details['attachment'])) {
        $filename = basename($email_details['attachment']);
        $attachments[$filename] = file_get_contents($email_details['attachment']);
    }

    if (send_email(
        $smtp,
        $account['email'],
        $account['name'],
        $email_details['to'],
        $email_details['subject'],
        $email_details['body'],
        $email_details['cc'],
        $email_details['bcc'],
        $attachments
    )) {
        echo "Email sent successfully from {$account['email']}\n";
        log_email($config, $account['email'], $email_details['to'], $email_details['subject'], 'Success');
    }

    fwrite($smtp, "QUIT\r\n");
    fclose($smtp);
} catch (Exception $e) {
    echo "Error: " . $e->getMessage() . "\n";
    log_email($config, $account['email'], $email_details['to'], $email_details['subject'], 'Failed: ' . $e->getMessage());
}