<?php
function send_email($smtp, $from, $from_name, $to, $subject, $body, $cc = [], $bcc = [], $attachments = []) {
    $boundary = md5(time());

    $headers = [
        "From: $from_name <$from>",
        "To: $to",
        "Subject: =?UTF-8?B?" . base64_encode($subject) . "?=",
        "MIME-Version: 1.0",
        "Content-Type: multipart/mixed; boundary=\"$boundary\"",
    ];

    if (!empty($cc)) {
        $headers[] = "Cc: " . implode(', ', $cc);
    }

    if (!empty($bcc)) {
        $headers[] = "Bcc: " . implode(', ', $bcc);
    }

    $message = implode("\r\n", $headers) . "\r\n\r\n";
    $message .= "--$boundary\r\n";
    $message .= "Content-Type: text/plain; charset=UTF-8\r\n";
    $message .= "Content-Transfer-Encoding: base64\r\n\r\n";
    $message .= chunk_split(base64_encode($body)) . "\r\n";

    foreach ($attachments as $filename => $content) {
        $message .= "--$boundary\r\n";
        $message .= "Content-Type: application/octet-stream; name=\"$filename\"\r\n";
        $message .= "Content-Transfer-Encoding: base64\r\n";
        $message .= "Content-Disposition: attachment; filename=\"$filename\"\r\n\r\n";
        $message .= chunk_split(base64_encode($content)) . "\r\n";
    }

    $message .= "--$boundary--\r\n";

    fwrite($smtp, "MAIL FROM: <$from>\r\n");
    $response = fgets($smtp);
    if (substr($response, 0, 3) !== '250') {
        throw new Exception("MAIL FROM failed: $response");
    }

    $recipients = array_merge([$to], $cc, $bcc);
    foreach ($recipients as $recipient) {
        fwrite($smtp, "RCPT TO: <$recipient>\r\n");
        $response = fgets($smtp);
        if (substr($response, 0, 3) !== '250') {
            throw new Exception("RCPT TO failed for $recipient: $response");
        }
    }

    fwrite($smtp, "DATA\r\n");
    $response = fgets($smtp);
    if (substr($response, 0, 3) !== '354') {
        throw new Exception("DATA command failed: $response");
    }

    fwrite($smtp, $message . "\r\n.\r\n");
    $response = fgets($smtp);
    if (substr($response, 0, 3) !== '250') {
        throw new Exception("Message sending failed: $response");
    }

    return true;
}